@@ -10,6 +10,7 @@ package Foo;
 use Test::More tests => 4;
 use base 'Class::DBI';
 use_ok("Class::DBI::AsForm");
+*type_of = sub { "varchar" };
 
 Foo->columns(All => qw/id bar baz/);
 like(Foo->to_field("baz"), qr/<input type="text" name="baz"/,
@@ -21,7 +22,7 @@ is(Foo->to_field("bar"), '<select name="bar">
 </select>',
     "Select OK");
 
-my $x = bless({id => 1, bar => Bar->retrieve_all(), baz => "Hello there"}), "Foo";
+my $x = bless({id => 1, bar => Bar->retrieve_all(), baz => "Hello there"}, "Foo");
 my %cgi = ( id => '<input type="text" name="id" value="1" />',
     bar => '<select name="bar">
 <option selected="selected" value="1">Hi</option>
